@@ -83,8 +83,13 @@ class PostDetailView(MetaSidebar, DetailView):
     def get_context_data(self, **kwargs):
         context = super(PostDetailView, self).get_context_data(**kwargs)
         comments = mymodels.Comments.objects.filter(thread_id=self.obj.thread_id)
+        try:
+            postimages = self.obj.photo.all()
+        except:
+            postimages = False
         context.update({
             'title': self.obj.title,
+            'post_images': postimages,
             'comments': comments,
         })
         return context
@@ -174,32 +179,4 @@ class AJAXArchive(ListView):
             'year_hoy': year_hoy,
             'results': results,
         })
-        return context
-
-def cronAddDisqusComments(request, id=''):
-    if conf.DISQUS_SYNC:
-        last_comment = mymodels.Comments.objects.all().order_by('-date')
-        last_date_imported='2003-04-24 13:25:09'
-        if last_comment:
-            last_date_imported=str(last_comment[0].date).replace('+00:00','')
-        print last_date_imported
-        try:
-            api = DisqusAPI(conf.DISQUS_API_SECRET, conf.DISQUS_API_PUBLIC)
-            for result in api.forums.listPosts(forum=conf.DISQUS_WEBSITE_SHORTNAME, limit='100', order='asc', since=last_date_imported):
-                if not mymodels.Comments.objects.filter(comment_id=result['id']):
-                    newcomment = mymodels.Comments.objects.create(comment_id=result['id'], date=result['createdAt'].replace('T',' '))
-                    newcomment.thread_id = result['thread']
-                    newcomment.forum_id = conf.DISQUS_WEBSITE_SHORTNAME
-                    newcomment.body = result['message']
-                    newcomment.author_name = result['author']['name']
-                    newcomment.author_url = result['author']['url']
-                    newcomment.author_email = result['author']['emailHash']
-                    newcomment.save()
-        except:
-            pass
-
-    output = "done"
-    return HttpResponse(output)
-
-
-
+        return context
\ No newline at end of file
